/*
 * Instance.cpp
 * 
 * Copyright (C) 2008 Matthias Schiffer <matthias@gamezock.de>
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <iostream>
#include "Instance.h"
#include "Gui/Window.h"

namespace ZoomEdit {

guint Instance::instances = 0;

Instance::Instance() : window(NULL) {
  instances++;
  
#ifdef GLIBMM_EXCEPTIONS_ENABLED
  try
  {
    xml = Gnome::Glade::Xml::create("zoomedit.glade");
  }
  catch(const Gnome::Glade::XmlError& ex)
  {
    std::cerr << ex.what() << std::endl;
    return;
  }
#else
  std::auto_ptr<Gnome::Glade::XmlError> error;
  xml = Gnome::Glade::Xml::create("zoomedit.glade", "", "", error);
  if(error.get())
  {
    std::cerr << error->what() << std::endl;
    return;
  }
#endif
  
  xml->get_widget_derived("WindowMain", window);
  if(!window) {
    xml.clear();
    return;
  }
  
  window->signal_hide().connect(sigc::mem_fun(this, &Instance::destroy));
  
  window->show();
}

Instance::~Instance() {
  if(window)
    delete window;
  
  instances--;
  if(!instances)
    Gtk::Main::quit();
}

bool Instance::create() {
  Instance *instance = new Instance();
  
  if(!instance->xml) {
    delete instance;
    return false;
  }
  
  return true;
}

void Instance::destroy() {
  delete this;
}

}
